/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 64

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug;
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w;
typedef struct tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw;
typedef struct tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ;
typedef struct tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg;
typedef struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg;
typedef struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ;
typedef struct tySequence__9brg1xNurxcus33lU4IE1Dw tySequence__9brg1xNurxcus33lU4IE1Dw;
typedef struct tySequence__oYkV9aFZe0MXcEAprJaOUsA tySequence__oYkV9aFZe0MXcEAprJaOUsA;
typedef struct tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q;
typedef struct tySequence__Mh9agqM29bm9aP5AUL1x7dZGA tySequence__Mh9agqM29bm9aP5AUL1x7dZGA;
typedef struct tySequence__arD7Tw6eD6lvOczWZl9buNg tySequence__arD7Tw6eD6lvOczWZl9buNg;
typedef struct tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw;
typedef struct tySequence__jWKvSdankQPoT5bw9cBU9aiw tySequence__jWKvSdankQPoT5bw9cBU9aiw;
typedef struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw;
typedef struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ;
typedef struct tySequence__YceFcaugL2PWNtVbyffD9bQ tySequence__YceFcaugL2PWNtVbyffD9bQ;
typedef struct tySequence__d4l6E4jBnTQ3BEfsLOpmEQ tySequence__d4l6E4jBnTQ3BEfsLOpmEQ;
typedef struct tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw tySequence__Bis5AbpONWcIRrPyPJS8Yw;
typedef struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA tyObject_Table__fdKWDDO1P17zvuQPReVgRA;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ tySequence__bWZXqEvLFwhLvAqSRoFNgQ;
typedef struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA;
typedef struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw tyObject_Table__IioUJGdqPI6xC7S7QF8MBw;
typedef struct tySequence__Qr6E8eH7btq79cFKGaJfGLw tySequence__Qr6E8eH7btq79cFKGaJfGLw;
typedef struct tyObject_Table__G1v8c16HePOldLeucwe05Q tyObject_Table__G1v8c16HePOldLeucwe05Q;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA;
typedef struct tySequence__23SMqauuRsbDANhthj9bWlA tySequence__23SMqauuRsbDANhthj9bWlA;
typedef struct tyObject_Table__NttoEzoiq5CiphZe81oadg tyObject_Table__NttoEzoiq5CiphZe81oadg;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg tyObject_Table__nagDFX4QHx0s6Fvma9blmSg;
typedef struct tySequence__pHNq3oXj9av2sEUdqaqeZjw tySequence__pHNq3oXj9av2sEUdqaqeZjw;
typedef struct tySequence__PzqTLBFNawCGiqTk0UORYw tySequence__PzqTLBFNawCGiqTk0UORYw;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg;
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw tySequence__pK3qSsBZwdXd6qyUMkd5Jw;
typedef struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ;
typedef struct tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig;
typedef struct tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg;
typedef struct tySequence__MvZmat48bhe9b6x9aUD58D5Q tySequence__MvZmat48bhe9b6x9aUD58D5Q;
typedef struct tyObject_TIdentIter__Oi4goG2ACEsy9cyTe6OCPrA tyObject_TIdentIter__Oi4goG2ACEsy9cyTe6OCPrA;
typedef struct tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;
typedef struct tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w;
typedef struct tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg;
typedef struct tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ;
typedef struct tyTuple__KlSLWBROOViO04uLQHu7ig tyTuple__KlSLWBROOViO04uLQHu7ig;
typedef struct tyTuple__DJxbl4DYEJfb29cy1MYaUPQ tyTuple__DJxbl4DYEJfb29cy1MYaUPQ;
typedef struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ tyTuple__NAaJgGVgNmlGoqmiWxdOHQ;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__quA39a2QdEQU9cSEIUSibApQ tyTuple__quA39a2QdEQU9cSEIUSibApQ;
typedef struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__wcNatyuf8WOqAhGLhSvgiw tyTuple__wcNatyuf8WOqAhGLhSvgiw;
typedef struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg;
typedef struct tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g;
typedef struct tyTuple__euPCXX9bc3XzndEhYlqNS7g tyTuple__euPCXX9bc3XzndEhYlqNS7g;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg;
typedef struct tyTuple__zwpS6d6iewrdlBSTNFoyVA tyTuple__zwpS6d6iewrdlBSTNFoyVA;

/* section: NIM_merge_TYPES */
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg flags;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
} _kind_4;
struct {tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
} _kind_5;
struct {tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* sons;
} _kind_6;
};
NimStringDesc* comment;
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
NimStringDesc* s;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* next;
NI h;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
typedef NU16 tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw;
typedef NU8 tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w;
typedef NU8 tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w {
  RootObj Sup;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg {
NI elems;
NI counter;
NI max;
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* head;
tySequence__9brg1xNurxcus33lU4IE1Dw* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q {
NI counter;
tySequence__Mh9agqM29bm9aP5AUL1x7dZGA* data;
};
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__RcJNn9bSvWdJgUmA1O6sbHA) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
typedef NU32 tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ;
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__39auogS0nN05zO6JrT7za9cQ) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__msQKNa7Ucgnt49aAZ3YRJww) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, void* ClE_0);
void* ClE_0;
} tyProc__7JwrY3AhkVNlleAJXClX9cw;
typedef NU32 tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__qlV9aWvA5wrWVg9bI5PqwJyA) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig, tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw filter, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
typedef N_NIMCALL_PTR(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, tyProc__PiEiMdzXg9bcm3lEo4Q6iNw) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
typedef struct {
N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, ClP_0) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, void* ClE_0);
void* ClE_0;
} tyProc__3cacbJ4la9bDJNibHybQSnA;
typedef struct {
N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, ClP_0) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, void* ClE_0);
void* ClE_0;
} tyProc__L4XfH7VEp8aJssG3EbEBaQ;
typedef NU8 tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg;
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__9amcenQyXzP9cCQNnXZVgnYQ) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* dc, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg op, NI col);
typedef NU16 tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
struct tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w {
tySequence__Bis5AbpONWcIRrPyPJS8Yw* data;
NI counter;
};
struct tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug {
  tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w Sup;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* enforceVoidContext;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* currentScope;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* importTable;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* topLevelScope;
tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ* p;
tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg* matchedConcept;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* friendModules;
NI instCounter;
NI* templInstCounter;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg ambiguousSymbols;
NI inGenericContext;
NI inStaticContext;
NI inUnrolledContext;
NI compilesContextId;
NI compilesContextIdGenerator;
NI inGenericInst;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* converters;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* patterns;
tySequence__oYkV9aFZe0MXcEAprJaOUsA* optionStack;
tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q symMapping;
tySequence__arD7Tw6eD6lvOczWZl9buNg* libs;
tyProc__RcJNn9bSvWdJgUmA1O6sbHA semConstExpr;
tyProc__39auogS0nN05zO6JrT7za9cQ semExpr;
tyProc__39auogS0nN05zO6JrT7za9cQ semTryExpr;
tyProc__RcJNn9bSvWdJgUmA1O6sbHA semTryConstExpr;
tyProc__msQKNa7Ucgnt49aAZ3YRJww computeRequiresInit;
tyProc__7JwrY3AhkVNlleAJXClX9cw hasUnresolvedArgs;
tyProc__39auogS0nN05zO6JrT7za9cQ semOperand;
tyProc__RcJNn9bSvWdJgUmA1O6sbHA semConstBoolExpr;
tyProc__qlV9aWvA5wrWVg9bI5PqwJyA semOverloadedCall;
tyProc__PiEiMdzXg9bcm3lEo4Q6iNw semTypeNode;
tyProc__3cacbJ4la9bDJNibHybQSnA semInferredLambda;
tyProc__L4XfH7VEp8aJssG3EbEBaQ semGenerateInstance;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg includedFiles;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA pureEnumFields;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA userPragmas;
tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw* evalContext;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg unknownIdents;
tySequence__jWKvSdankQPoT5bw9cBU9aiw* generics;
NI topStmts;
NI lastGenericIdx;
NI hloLoopDetector;
NI inParallelStmt;
tyProc__9amcenQyXzP9cCQNnXZVgnYQ instTypeBoundOp;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* selfName;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA signatures;
NimStringDesc* recursiveDep;
NIM_BOOL suggestionsMade;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
NI inTypeContext;
tySequence__YceFcaugL2PWNtVbyffD9bQ* typesWithOps;
tySequence__d4l6E4jBnTQ3BEfsLOpmEQ* unusedImports;
tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w exportIndirections;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastTLineInfo;
};
struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__OLX364rHC66WkzRbMp49aQg[64];
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__6GDJmNRiFxkWAAdMgUie8g[70];
struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA {
char dummy;
};
struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw {
tySequence__Qr6E8eH7btq79cFKGaJfGLw* data;
NI counter;
};
struct tyObject_Table__G1v8c16HePOldLeucwe05Q {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__c6vdo1yHyj19b9bS17tijS2w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__d5yEkT9aXkAtHvVerr7IeCQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(void, tyProc__sP1I7TbCn358eLy9bX4IphA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA {
tySequence__23SMqauuRsbDANhthj9bWlA* data;
NI counter;
};
struct tyObject_Table__NttoEzoiq5CiphZe81oadg {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg {
tySequence__pHNq3oXj9av2sEUdqaqeZjw* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__3TeLOx1euAsRk3YCaQCuPg) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* actual);
struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* modules;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA packageSyms;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg deps;
tyObject_Table__fdKWDDO1P17zvuQPReVgRA importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* usageSym;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* owners;
tySequence__bWZXqEvLFwhLvAqSRoFNgQ* methods;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* systemModule;
tyArray__OLX364rHC66WkzRbMp49aQg sysTypes;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA compilerprocs;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA exposed;
tyArray__6GDJmNRiFxkWAAdMgUie8g intTypeCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opContains;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opNot;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* emptyNode;
tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA incr;
tyObject_Table__IioUJGdqPI6xC7S7QF8MBw canonTypes;
tyObject_Table__G1v8c16HePOldLeucwe05Q symBodyHashes;
tyProc__c6vdo1yHyj19b9bS17tijS2w importModuleCallback;
tyProc__d5yEkT9aXkAtHvVerr7IeCQ includeFileCallback;
tyProc__sP1I7TbCn358eLy9bX4IphA recordStmt;
tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA cacheSeqs;
tyObject_Table__NttoEzoiq5CiphZe81oadg cacheCounters;
tyObject_Table__nagDFX4QHx0s6Fvma9blmSg cacheTables;
tySequence__PzqTLBFNawCGiqTk0UORYw* passes;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinition;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinitionResolveForward;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onUsage;
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* globalDestructors;
tyProc__sP1I7TbCn358eLy9bX4IphA strongSemCheck;
tyProc__3TeLOx1euAsRk3YCaQCuPg compatibleProps;
};
struct tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw {
NI depthLevel;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA symbols;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* parent;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g;
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU64 tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw;
typedef NU8 tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw;
typedef NU8 tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ;
typedef NU8 tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ;
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU8 tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU8 tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ;
typedef NU8 tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result, void* ClE_0);
void* ClE_0;
} tyProc__YD0MR9bJ2x4beJkZdnjXN9cA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity, void* ClE_0);
void* ClE_0;
} tyProc__oL9coyIA2VDTGdUcur9aL9bew;
struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw {
tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
tyObject_Target__9abOl5DLX8suLujOaHSvGzw target;
NI linesCompiled;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw globalOptions;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* macrosToExpand;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* arcToExpand;
tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A m;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd;
tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw selectedGC;
tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ exc;
NI verbosity;
NI numberOfProcessors;
NimStringDesc* evalExpr;
NF lastCmdTime;
tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ symbolFiles;
tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA cCompiler;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg modifiedyNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg cmdlineNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg foreignPackageNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* configVars;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* dllOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* moduleOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
NIM_BOOL lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__pK3qSsBZwdXd6qyUMkd5Jw* toCompile;
tyProc__YD0MR9bJ2x4beJkZdnjXN9cA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__oL9coyIA2VDTGdUcur9aL9bew structuredErrorHook;
NimStringDesc* cppCustomNamespace;
tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* vmProfileData;
};
typedef NimStringDesc* tyArray__Re75IspeoxXy2oCZHwcRrA[2];
struct tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg {
NI h;
};
typedef NU8 tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU8 tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw;
typedef NU8 tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA;
typedef NU64 tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tyArray__PsPyPA45AAjHu4uDGHNjTg[6];
struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA callConv;
tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw flags;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyArray__PsPyPA45AAjHu4uDGHNjTg attachedOps;
tySequence__MvZmat48bhe9b6x9aUD58D5Q* methods;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeInst;
NI uniqueId;
};
typedef NU8 tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef NU8 tySet_tyEnum_TLookupFlag__ObWMY5GMSl1GiMcrKaAhKQ;
typedef NU8 tyEnum_TLookupFlag__ObWMY5GMSl1GiMcrKaAhKQ;
struct tyObject_TIdentIter__Oi4goG2ACEsy9cyTe6OCPrA {
NI h;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
};
typedef NU8 tyEnum_TOverloadIterMode__xCku9a0wtzKQQBbzX1t6btg;
struct tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ {
tyObject_TIdentIter__Oi4goG2ACEsy9cyTe6OCPrA it;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m;
tyEnum_TOverloadIterMode__xCku9a0wtzKQQBbzX1t6btg mode;
NI symChoiceIndex;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg inSymChoice;
};
struct tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg {
tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key;
RootObj* val;
};
struct tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* genericSym;
tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* inst;
};
struct tyTuple__KlSLWBROOViO04uLQHu7ig {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field0;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field1;
};
struct tyTuple__DJxbl4DYEJfb29cy1MYaUPQ {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field0;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field1;
};
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
NI Field0;
NI Field1;
};
struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ {
NI Field0;
tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ Field1;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyTuple__quA39a2QdEQU9cSEIUSibApQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg {
tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g* root;
NI entries;
};
struct tyTuple__wcNatyuf8WOqAhGLhSvgiw {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, tyProc__8ooe5vdoqmvpHnfXV29bP3w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__A7Sdoem70tRxSEmKrf9cmyg) (tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__EAEKmBUgKFg29agoUGtzDEQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyTuple__euPCXX9bc3XzndEhYlqNS7g {
tyProc__8ooe5vdoqmvpHnfXV29bP3w Field0;
tyProc__A7Sdoem70tRxSEmKrf9cmyg Field1;
tyProc__EAEKmBUgKFg29agoUGtzDEQ Field2;
NIM_BOOL Field3;
};
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA;
struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA flags;
NimStringDesc* customArgs;
};
struct tyTuple__zwpS6d6iewrdlBSTNFoyVA {
NI Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__9brg1xNurxcus33lU4IE1Dw {
  TGenericSeq Sup;
  tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* data[SEQ_DECL_SIZE];
};
struct tySequence__oYkV9aFZe0MXcEAprJaOUsA {
  TGenericSeq Sup;
  tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w* data[SEQ_DECL_SIZE];
};
struct tySequence__Mh9agqM29bm9aP5AUL1x7dZGA {
  TGenericSeq Sup;
  tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg data[SEQ_DECL_SIZE];
};
struct tySequence__arD7Tw6eD6lvOczWZl9buNg {
  TGenericSeq Sup;
  tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* data[SEQ_DECL_SIZE];
};
struct tySequence__jWKvSdankQPoT5bw9cBU9aiw {
  TGenericSeq Sup;
  tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ data[SEQ_DECL_SIZE];
};
struct tySequence__YceFcaugL2PWNtVbyffD9bQ {
  TGenericSeq Sup;
  tyTuple__KlSLWBROOViO04uLQHu7ig data[SEQ_DECL_SIZE];
};
struct tySequence__d4l6E4jBnTQ3BEfsLOpmEQ {
  TGenericSeq Sup;
  tyTuple__DJxbl4DYEJfb29cy1MYaUPQ data[SEQ_DECL_SIZE];
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw {
  TGenericSeq Sup;
  tyTuple__NAaJgGVgNmlGoqmiWxdOHQ data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ {
  TGenericSeq Sup;
  tyTuple__quA39a2QdEQU9cSEIUSibApQ data[SEQ_DECL_SIZE];
};
struct tySequence__Qr6E8eH7btq79cFKGaJfGLw {
  TGenericSeq Sup;
  tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__23SMqauuRsbDANhthj9bWlA {
  TGenericSeq Sup;
  tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__pHNq3oXj9av2sEUdqaqeZjw {
  TGenericSeq Sup;
  tyTuple__wcNatyuf8WOqAhGLhSvgiw data[SEQ_DECL_SIZE];
};
struct tySequence__PzqTLBFNawCGiqTk0UORYw {
  TGenericSeq Sup;
  tyTuple__euPCXX9bc3XzndEhYlqNS7g data[SEQ_DECL_SIZE];
};
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw {
  TGenericSeq Sup;
  tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg data[SEQ_DECL_SIZE];
};
struct tySequence__MvZmat48bhe9b6x9aUD58D5Q {
  TGenericSeq Sup;
  tyTuple__zwpS6d6iewrdlBSTNFoyVA data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, noidentError__HVvM5T79c59bpcZcfRadKowg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* origin);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw renderFlags);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__Q6JNH4uRwLyZrj0dJakHew)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg, tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*, getIdent__9coBOmdXN09be4rJvXK6fQGQ)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* ic, NimStringDesc* identifier);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*, considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* origin);
N_LIB_PRIVATE N_NIMCALL(void*, newObj)(TNimType* typ, NI size);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(void, newStrTable__mHe4qdIbMriO4fD2l0WhLA)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA* Result);
static N_INLINE(NI, scopeDepth__qQCrsfEC1pwv9ag9cRhlJF6wsemdata)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, strTableInclReportConflict__tsV7rrfL6ZnfCXBjJk0jUA)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA* t, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* n, NIM_BOOL onConflictKeepOld);
N_LIB_PRIVATE N_NIMCALL(void, wrongRedefinition__m38oZS3DB39a2RtTLWidA5w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q conflictsWith);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___aQsiZUvE4SFfnWyKx1JgKA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, ensureNoMissingOrUnusedSymbols__cjXWCeavUYf01OcsU7rblQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, initTabIter__Ag5U6LHpF7iSy3G6AzXM9cw)(tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg* ti, tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatSingleElem)(NimStringDesc* formatstr, NimStringDesc* a);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getSymRepr__q0Idm3DQlYmoqr1FN0Wn2g)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getProcHeader__bRG2xX9ar5tfMW3c7xo9ccKQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw prefer, NIM_BOOL getDeclarationPath);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, nextIter__Ag5U6LHpF7iSy3G6AzXM9cw_2)(tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg* ti, tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab);
N_LIB_PRIVATE N_NIMCALL(void, rawCloseScope__TX9bi5b9bIHR13FiwHwV59a4w_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(void, addInterfaceOverloadableSymAt__HcojHyPBYsbchSQtmBqThg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(void, addOverloadableSymAt__f3XpqDor3DTwMRlVDgX3Gw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA t, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name);
N_LIB_PRIVATE N_NIMCALL(void, strTableAdd__tyTgUybFIoow4CX2l5beug)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA* t, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* n);
N_LIB_PRIVATE N_NIMCALL(void, addInterfaceDeclAux__aPXKqZJT9c7r7gT8X3uZAHw_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(void, addInterfaceDecl__aPXKqZJT9c7r7gT8X3uZAHw_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(void, addDecl__aPXKqZJT9c7r7gT8X3uZAHw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(void, closeScope__TX9bi5b9bIHR13FiwHwV59a4w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, skipAlias__5qYRPQsu9attXO2xg5lnFVQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, replaceDeprecated__gwkcrA9aySxcttSaRoWR78w)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* oldSym, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* newSym);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, searchInScopes__Drn1sJCJSwUUo03qKJigUw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, searchInScopes__Jp5sb3DT9aETEb2x58UOk6g)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* s, tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw filter);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, initIdentIter__9bOoZ7latEpanbVkjFO7xFQ)(tyObject_TIdentIter__Oi4goG2ACEsy9cyTe6OCPrA* ti, tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, nextIdentIter__9bSCoSykDuXHhkzoBXiof6Q)(tyObject_TIdentIter__Oi4goG2ACEsy9cyTe6OCPrA* ti, tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab);
N_LIB_PRIVATE N_NIMCALL(void, errorUndeclaredIdentifier__2jJM9bqw5w9caMyqez0JSuZw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, errorSym__CLMmoDuBHkJLvNsKvljGNw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newSym__IXbidcxhXTQGZY9abN63Cxg)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw symKind, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, errorType__9aXTnVBVS5pbBC3zrwMhttg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__R6uRTGpl30Ofaw4Ni3vawA)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
N_LIB_PRIVATE N_NIMCALL(void, errorUseQualifier__t5EWYooFsFPeMiRTzdCWFw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, typeToString__QlvraUan7WbHowhAbvDvdA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw prefer);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TLookupFlag__ObWMY5GMSl1GiMcrKaAhKQ flags);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(void, initIntSet__n8oDZMn19bEdodSnrBQB9a1Q)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* Result);
N_LIB_PRIVATE N_NIMCALL(void, incl__jENnK9c9bPE73pKmo2vYjpqg)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, firstIdentExcluding__ZgFGN4FdEZomWhiPqs5O3Q)(tyObject_TIdentIter__Oi4goG2ACEsy9cyTe6OCPrA* ti, tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* s, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* excluding);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, nextIdentExcluding__nWv58txbq3B5NUvjC6qnSA)(tyObject_TIdentIter__Oi4goG2ACEsy9cyTe6OCPrA* ti, tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* excluding);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, addUniqueSym__77zA8kzVYm6Us7mD6cMg6A)(tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, addDeclAt__HcojHyPBYsbchSQtmBqThg_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, initOverloadIter__yTTeeqtnENsm0xyCro9a61w)(tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ* o, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, nextOverloadIter__yTTeeqtnENsm0xyCro9a61w_2)(tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ* o, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NIM_BOOL, isShadowScope__S1jnHolp9bBTKeEAk0tUmLwlookups)(tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* s);

/* section: NIM_merge_DATA */
STRING_LITERAL(TM__3uzV357076dKeFHtnMZm2A_2, "in expression \'", 15);
STRING_LITERAL(TM__3uzV357076dKeFHtnMZm2A_3, "\': ", 3);
STRING_LITERAL(TM__3uzV357076dKeFHtnMZm2A_4, "identifier expected, but found \'", 32);
STRING_LITERAL(TM__3uzV357076dKeFHtnMZm2A_5, "\'", 1);
STRING_LITERAL(TM__3uzV357076dKeFHtnMZm2A_7, "/home/runner/work/nightlies/nightlies/nim/compiler/lookups.nim", 62);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__3uzV357076dKeFHtnMZm2A_6 = {((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_7),
((NI) 23),
((NI) 12)}
;
STRING_LITERAL(TM__3uzV357076dKeFHtnMZm2A_8, "<Error>", 7);
extern TNimType NTI__N89ckikRqMir57209a3tEeqw_;
STRING_LITERAL(TM__3uzV357076dKeFHtnMZm2A_9, "redefinition of \'$1\'; previous declaration here: $2", 51);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__3uzV357076dKeFHtnMZm2A_10 = {((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_7),
((NI) 189),
((NI) 14)}
;
STRING_LITERAL(TM__3uzV357076dKeFHtnMZm2A_11, "implementation of \'$1\' expected", 31);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__3uzV357076dKeFHtnMZm2A_12 = {((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_7),
((NI) 174),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__3uzV357076dKeFHtnMZm2A_13 = {((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_7),
((NI) 183),
((NI) 17)}
;
STRING_LITERAL(TM__3uzV357076dKeFHtnMZm2A_14, "addOverloadableSymAt", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__3uzV357076dKeFHtnMZm2A_15 = {((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_7),
((NI) 223),
((NI) 17)}
;
STRING_LITERAL(TM__3uzV357076dKeFHtnMZm2A_16, "addInterfaceDeclAux", 19);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__3uzV357076dKeFHtnMZm2A_17 = {((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_7),
((NI) 215),
((NI) 23)}
;
STRING_LITERAL(TM__3uzV357076dKeFHtnMZm2A_18, "use ", 4);
STRING_LITERAL(TM__3uzV357076dKeFHtnMZm2A_19, " instead; ", 10);
STRING_LITERAL(TM__3uzV357076dKeFHtnMZm2A_20, " is deprecated", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__3uzV357076dKeFHtnMZm2A_21 = {((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_7),
((NI) 91),
((NI) 13)}
;
STRING_LITERAL(TM__3uzV357076dKeFHtnMZm2A_22, "undeclared identifier: \'", 24);
STRING_LITERAL(TM__3uzV357076dKeFHtnMZm2A_23, "\012This might be caused by a recursive module dependency:\012", 56);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__3uzV357076dKeFHtnMZm2A_24 = {((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_7),
((NI) 296),
((NI) 12)}
;
STRING_LITERAL(TM__3uzV357076dKeFHtnMZm2A_25, "err:", 4);
STRING_LITERAL(TM__3uzV357076dKeFHtnMZm2A_26, "ambiguous identifier: \'", 23);
STRING_LITERAL(TM__3uzV357076dKeFHtnMZm2A_27, " -- use one of the following:\012", 30);
STRING_LITERAL(TM__3uzV357076dKeFHtnMZm2A_28, "\012", 1);
STRING_LITERAL(TM__3uzV357076dKeFHtnMZm2A_29, "  ", 2);
STRING_LITERAL(TM__3uzV357076dKeFHtnMZm2A_30, ".", 1);
STRING_LITERAL(TM__3uzV357076dKeFHtnMZm2A_31, ": ", 2);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__3uzV357076dKeFHtnMZm2A_32 = {((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_7),
((NI) 287),
((NI) 12)}
;
STRING_LITERAL(TM__3uzV357076dKeFHtnMZm2A_33, "identifier expected, but got: ", 30);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__3uzV357076dKeFHtnMZm2A_34 = {((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_7),
((NI) 371),
((NI) 18)}
;
STRING_LITERAL(TM__3uzV357076dKeFHtnMZm2A_35, "lookUp", 6);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__3uzV357076dKeFHtnMZm2A_36 = {((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_7),
((NI) 317),
((NI) 17)}
;

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__i80o3k0SgEI5gTRCzYdyWAsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, noidentError__HVvM5T79c59bpcZcfRadKowg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* origin) {
	NimStringDesc* m;
	NimStringDesc* T7_;
	NimStringDesc* T8_;
	m = ((NimStringDesc*) NIM_NIL);
	{
		NimStringDesc* T5_;
		NimStringDesc* T6_;
		if (!!((origin == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA3_;
		T5_ = (NimStringDesc*)0;
		T6_ = (NimStringDesc*)0;
		T6_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(origin, 0);
		T5_ = rawNewString((T6_ ? T6_->Sup.len : 0) + 18);
appendString(T5_, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_2));
appendString(T5_, T6_);
appendString(T5_, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_3));
		m = resizeString(m, (T5_ ? T5_->Sup.len : 0) + 0);
appendString(m, T5_);
	}
	LA3_: ;
	T7_ = (NimStringDesc*)0;
	T8_ = (NimStringDesc*)0;
	T8_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 0);
	T7_ = rawNewString((T8_ ? T8_->Sup.len : 0) + 33);
appendString(T7_, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_4));
appendString(T7_, T8_);
appendString(T7_, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_5));
	m = resizeString(m, (T7_ ? T7_->Sup.len : 0) + 0);
appendString(m, T7_);
	liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), m, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__3uzV357076dKeFHtnMZm2A_6, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*, considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* origin) {
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* result;
	result = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	{
		result = (*n)._kind_5.ident;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		result = (*(*n)._kind_4.sym).name;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53):
	{
		NI T4_;
		T4_ = (NI)0;
		T4_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		switch (T4_) {
		case ((NI) 0):
		{
			noidentError__HVvM5T79c59bpcZcfRadKowg((*(*c).graph).config, n, origin);
			result = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_8));
		}
		break;
		case ((NI) 1):
		{
			result = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*n)._kind_6.sons->data[((NI) 0)], origin);
		}
		break;
		default:
		{
			NimStringDesc* id;
			id = ((NimStringDesc*) NIM_NIL);
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
						if (!(i_2 < colontmp_)) goto LA10;
						i = i_2;
						x = (*n)._kind_6.sons->data[i];
						switch ((*x).kind) {
						case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
						{
							id = resizeString(id, ((*(*x)._kind_5.ident).s ? (*(*x)._kind_5.ident).s->Sup.len : 0) + 0);
appendString(id, (*(*x)._kind_5.ident).s);
						}
						break;
						case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
						{
							id = resizeString(id, ((*(*(*x)._kind_4.sym).name).s ? (*(*(*x)._kind_4.sym).name).s->Sup.len : 0) + 0);
appendString(id, (*(*(*x)._kind_4.sym).name).s);
						}
						break;
						case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15):
						case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
						{
							NimStringDesc* T14_;
							T14_ = (NimStringDesc*)0;
							T14_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(x, 0);
							id = resizeString(id, (T14_ ? T14_->Sup.len : 0) + 0);
appendString(id, T14_);
						}
						break;
						default:
						{
							noidentError__HVvM5T79c59bpcZcfRadKowg((*(*c).graph).config, n, origin);
							result = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_8));
						}
						break;
						}
						i_2 += ((NI) 1);
					} LA10: ;
				}
			}
			result = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, id);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 57):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 56):
	{
		{
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA19_;
			result = (*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name;
		}
		goto LA17_;
		LA19_: ;
		{
			noidentError__HVvM5T79c59bpcZcfRadKowg((*(*c).graph).config, n, origin);
			result = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_8));
		}
		LA17_: ;
	}
	break;
	default:
	{
		noidentError__HVvM5T79c59bpcZcfRadKowg((*(*c).graph).config, n, origin);
		result = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_8));
	}
	break;
	}
	return result;
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(NI, scopeDepth__qQCrsfEC1pwv9ag9cRhlJF6wsemdata)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	NI result;
	result = (NI)0;
	{
		if (!!(((*c).currentScope == ((tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*) NIM_NIL)))) goto LA3_;
		result = (*(*c).currentScope).depthLevel;
	}
	goto LA1_;
	LA3_: ;
	{
		result = ((NI) 0);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*, openScope__HbQKk9aDdsJVs9bASTXwa5Lw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* result;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T1_;
	NI T2_;
	result = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T1_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T1_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*) newObj((&NTI__N89ckikRqMir57209a3tEeqw_), sizeof(tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw));
	asgnRef((void**) (&(*T1_).parent), (*c).currentScope);
	newStrTable__mHe4qdIbMriO4fD2l0WhLA((&(*T1_).symbols));
	T2_ = (NI)0;
	T2_ = scopeDepth__qQCrsfEC1pwv9ag9cRhlJF6wsemdata(c);
	(*T1_).depthLevel = (NI)(T2_ + ((NI) 1));
	result = T1_;
	asgnRef((void**) (&(*c).currentScope), result);
	return result;
}
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory(p, ((int) 0), size);
}
N_LIB_PRIVATE N_NIMCALL(void, wrongRedefinition__m38oZS3DB39a2RtTLWidA5w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q conflictsWith) {
	{
		tyArray__Re75IspeoxXy2oCZHwcRrA T5_;
		NimStringDesc* T6_;
		if (!!(((*(*(*c).graph).config).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 18)))) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
		T5_[0] = copyString(s);
		T5_[1] = dollar___aQsiZUvE4SFfnWyKx1JgKA((*(*c).graph).config, conflictsWith);
		T6_ = (NimStringDesc*)0;
		T6_ = nsuFormatOpenArray(((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_9), T5_, 2);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T6_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__3uzV357076dKeFHtnMZm2A_10, NIM_FALSE);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addDecl__aPXKqZJT9c7r7gT8X3uZAHw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* conflict;
	conflict = strTableInclReportConflict__tsV7rrfL6ZnfCXBjJk0jUA((&(*(*c).currentScope).symbols), sym, NIM_TRUE);
	{
		if (!!((conflict == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA3_;
		wrongRedefinition__m38oZS3DB39a2RtTLWidA5w(c, (*sym).info, (*(*sym).name).s, (*conflict).info);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getSymRepr__q0Idm3DQlYmoqr1FN0Wn2g)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	switch ((*s).kind) {
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12) ... ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7):
	{
		result = getProcHeader__bRG2xX9ar5tfMW3c7xo9ccKQ(conf, s, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0), NIM_TRUE);
	}
	break;
	default:
	{
		result = copyString((*(*s).name).s);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, ensureNoMissingOrUnusedSymbols__cjXWCeavUYf01OcsU7rblQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope) {
	tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg it;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	NI missingImpls;
	nimZeroMem((void*)(&it), sizeof(tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg));
	s = initTabIter__Ag5U6LHpF7iSy3G6AzXM9cw((&it), (*scope).symbols);
	missingImpls = ((NI) 0);
	{
		while (1) {
			if (!!((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA2;
			{
				NIM_BOOL T5_;
				T5_ = (NIM_BOOL)0;
				T5_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 4))&63U)))!=0);
				if (!(T5_)) goto LA6_;
				T5_ = !(((192 &((NU32)1<<((NU)((*s).kind)&31U)))!=0));
				LA6_: ;
				if (!T5_) goto LA7_;
				{
					NimStringDesc* T13_;
					NimStringDesc* T14_;
					if (!(missingImpls == ((NI) 0))) goto LA11_;
					T13_ = (NimStringDesc*)0;
					T13_ = getSymRepr__q0Idm3DQlYmoqr1FN0Wn2g((*(*c).graph).config, s);
					T14_ = (NimStringDesc*)0;
					T14_ = nsuFormatSingleElem(((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_11), T13_);
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*s).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T14_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__3uzV357076dKeFHtnMZm2A_12, NIM_FALSE);
				}
				LA11_: ;
				missingImpls += ((NI) 1);
			}
			goto LA3_;
			LA7_: ;
			{
				if (!((3 & (*s).flags) == 0)) goto LA16_;
				{
					if (!!(((3162137 &((NU32)1<<((NU)((*s).kind)&31U)))!=0))) goto LA20_;
					{
						NIM_BOOL T24_;
						NIM_BOOL T25_;
						T24_ = (NIM_BOOL)0;
						T25_ = (NIM_BOOL)0;
						T25_ = !(((*s).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
						if (!(T25_)) goto LA26_;
						T25_ = !((((*(*s).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 26))&63U)))!=0));
						LA26_: ;
						T24_ = T25_;
						if (!(T24_)) goto LA27_;
						T24_ = !(((*(*s).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12)));
						LA27_: ;
						if (!T24_) goto LA28_;
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*s).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 56), (*(*s).name).s, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__3uzV357076dKeFHtnMZm2A_13, NIM_FALSE);
					}
					LA28_: ;
				}
				LA20_: ;
			}
			goto LA3_;
			LA16_: ;
			LA3_: ;
			s = nextIter__Ag5U6LHpF7iSy3G6AzXM9cw_2((&it), (*scope).symbols);
		} LA2: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, rawCloseScope__TX9bi5b9bIHR13FiwHwV59a4w_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	asgnRef((void**) (&(*c).currentScope), (*(*c).currentScope).parent);
}
N_LIB_PRIVATE N_NIMCALL(void, closeScope__TX9bi5b9bIHR13FiwHwV59a4w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	ensureNoMissingOrUnusedSymbols__cjXWCeavUYf01OcsU7rblQ(c, (*c).currentScope);
	rawCloseScope__TX9bi5b9bIHR13FiwHwV59a4w_2(c);
}
N_LIB_PRIVATE N_NIMCALL(void, openShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T1_;
	T1_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T1_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*) newObj((&NTI__N89ckikRqMir57209a3tEeqw_), sizeof(tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw));
	asgnRef((void**) (&(*T1_).parent), (*c).currentScope);
	newStrTable__mHe4qdIbMriO4fD2l0WhLA((&(*T1_).symbols));
	(*T1_).depthLevel = scopeDepth__qQCrsfEC1pwv9ag9cRhlJF6wsemdata(c);
	asgnRef((void**) (&(*c).currentScope), T1_);
}
N_LIB_PRIVATE N_NIMCALL(void, addOverloadableSymAt__f3XpqDor3DTwMRlVDgX3Gw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* check;
{	{
		if (!!(((520256 &((NU32)1<<((NU)((*fn).kind)&31U)))!=0))) goto LA3_;
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, (*fn).info, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_14), TM__3uzV357076dKeFHtnMZm2A_15);
		goto BeforeRet_;
	}
	LA3_: ;
	check = strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ((*scope).symbols, (*fn).name);
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = !((check == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
		if (!(T7_)) goto LA8_;
		T7_ = !(((520256 &((NU32)1<<((NU)((*check).kind)&31U)))!=0));
		LA8_: ;
		if (!T7_) goto LA9_;
		wrongRedefinition__m38oZS3DB39a2RtTLWidA5w(c, (*fn).info, (*(*fn).name).s, (*check).info);
	}
	goto LA5_;
	LA9_: ;
	{
		strTableAdd__tyTgUybFIoow4CX2l5beug((&(*scope).symbols), fn);
	}
	LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addInterfaceDeclAux__aPXKqZJT9c7r7gT8X3uZAHw_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym) {
	{
		if (!(((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 1))&63U)))!=0)) goto LA3_;
		{
			if (!!(((*c).module == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA7_;
			strTableAdd__tyTgUybFIoow4CX2l5beug((&(*(*c).module)._kind_3.tab), sym);
		}
		goto LA5_;
		LA7_: ;
		{
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, (*sym).info, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_16), TM__3uzV357076dKeFHtnMZm2A_17);
		}
		LA5_: ;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addInterfaceOverloadableSymAt__HcojHyPBYsbchSQtmBqThg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym) {
	addOverloadableSymAt__f3XpqDor3DTwMRlVDgX3Gw(c, scope, sym);
	addInterfaceDeclAux__aPXKqZJT9c7r7gT8X3uZAHw_2(c, sym);
}
N_LIB_PRIVATE N_NIMCALL(void, addInterfaceDecl__aPXKqZJT9c7r7gT8X3uZAHw_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym) {
	addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, sym);
	addInterfaceDeclAux__aPXKqZJT9c7r7gT8X3uZAHw_2(c, sym);
}
N_LIB_PRIVATE N_NIMCALL(void, mergeShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_4)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* shadowScope;
	shadowScope = (*c).currentScope;
	rawCloseScope__TX9bi5b9bIHR13FiwHwV59a4w_2(c);
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
		tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg it;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
		sym = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		nimZeroMem((void*)(&it), sizeof(tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg));
		s = initTabIter__Ag5U6LHpF7iSy3G6AzXM9cw((&it), (*shadowScope).symbols);
		{
			while (1) {
				if (!!((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA3;
				sym = s;
				{
					if (!((520256 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0)) goto LA6_;
					addInterfaceOverloadableSymAt__HcojHyPBYsbchSQtmBqThg(c, (*c).currentScope, sym);
				}
				goto LA4_;
				LA6_: ;
				{
					addInterfaceDecl__aPXKqZJT9c7r7gT8X3uZAHw_3(c, sym);
				}
				LA4_: ;
				s = nextIter__Ag5U6LHpF7iSy3G6AzXM9cw_2((&it), (*shadowScope).symbols);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, closeShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_5)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, skipAlias__5qYRPQsu9attXO2xg5lnFVQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = !(((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 25)));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = s;
	}
	goto LA1_;
	LA5_: ;
	{
		result = (*s).owner;
		{
			if (!((*conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 7))) goto LA10_;
			replaceDeprecated__gwkcrA9aySxcttSaRoWR78w(conf, (*n).info, s, result);
		}
		goto LA8_;
		LA10_: ;
		{
			NimStringDesc* T13_;
			T13_ = (NimStringDesc*)0;
			T13_ = rawNewString(((*(*result).name).s ? (*(*result).name).s->Sup.len : 0) + ((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + 28);
appendString(T13_, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_18));
appendString(T13_, (*(*result).name).s);
appendString(T13_, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_19));
appendString(T13_, (*(*s).name).s);
appendString(T13_, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_20));
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 16), T13_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__3uzV357076dKeFHtnMZm2A_21, NIM_FALSE);
		}
		LA8_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, searchInScopes__Drn1sJCJSwUUo03qKJigUw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* s) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
{	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope;
		tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* current;
		scope = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
		current = (*c).currentScope;
		{
			while (1) {
				if (!!((current == ((tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*) NIM_NIL)))) goto LA3;
				scope = current;
				result = strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ((*scope).symbols, s);
				{
					if (!!((result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA6_;
					goto BeforeRet_;
				}
				LA6_: ;
				current = (*current).parent;
			} LA3: ;
		}
	}
	result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, searchInScopes__Jp5sb3DT9aETEb2x58UOk6g)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* s, tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw filter) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
{	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope;
		tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* current;
		scope = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
		current = (*c).currentScope;
		{
			while (1) {
				tyObject_TIdentIter__Oi4goG2ACEsy9cyTe6OCPrA ti;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* candidate;
				if (!!((current == ((tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*) NIM_NIL)))) goto LA3;
				scope = current;
				nimZeroMem((void*)(&ti), sizeof(tyObject_TIdentIter__Oi4goG2ACEsy9cyTe6OCPrA));
				candidate = initIdentIter__9bOoZ7latEpanbVkjFO7xFQ((&ti), (*scope).symbols, s);
				{
					while (1) {
						if (!!((candidate == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA5;
						{
							if (!((filter &((NU32)1<<((NU)((*candidate).kind)&31U)))!=0)) goto LA8_;
							result = candidate;
							goto BeforeRet_;
						}
						LA8_: ;
						candidate = nextIdentIter__9bSCoSykDuXHhkzoBXiof6Q((&ti), (*scope).symbols);
					} LA5: ;
				}
				current = (*current).parent;
			} LA3: ;
		}
	}
	result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, errorUndeclaredIdentifier__2jJM9bqw5w9caMyqez0JSuZw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* name) {
	NimStringDesc* err;
	NimStringDesc* T1_;
	T1_ = (NimStringDesc*)0;
	T1_ = rawNewString((name ? name->Sup.len : 0) + 25);
appendString(T1_, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_22));
appendString(T1_, name);
appendString(T1_, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_5));
	err = T1_;
	{
		if (!(((NI) 0) < ((*c).recursiveDep ? (*c).recursiveDep->Sup.len : 0))) goto LA4_;
		err = resizeString(err, 56);
appendString(err, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_23));
		err = resizeString(err, ((*c).recursiveDep ? (*c).recursiveDep->Sup.len : 0) + 0);
appendString(err, (*c).recursiveDep);
		asgnRef((void**) (&(*c).recursiveDep), ((NimStringDesc*) NIM_NIL));
	}
	LA4_: ;
	liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), err, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__3uzV357076dKeFHtnMZm2A_24, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, errorSym__CLMmoDuBHkJLvNsKvljGNw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* m;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T12_;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	m = n;
	{
		if (!((*m).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45))) goto LA3_;
		m = (*m)._kind_6.sons->data[((NI) 1)];
	}
	LA3_: ;
	{
		if (!((*m).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2) || (*m).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3) || (*m).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53))) goto LA7_;
		ident = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, m, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	}
	goto LA5_;
	LA7_: ;
	{
		NimStringDesc* T10_;
		NimStringDesc* T11_;
		T10_ = (NimStringDesc*)0;
		T11_ = (NimStringDesc*)0;
		T11_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(m, 0);
		T10_ = rawNewString((T11_ ? T11_->Sup.len : 0) + 4);
appendString(T10_, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_25));
appendString(T10_, T11_);
		ident = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, T10_);
	}
	LA5_: ;
	T12_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T12_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
	result = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 0), ident, T12_, (*n).info, 0);
	asgnRef((void**) (&(*result).typ), errorType__9aXTnVBVS5pbBC3zrwMhttg(c));
	(*result).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 33)) & 63);
	{
		NIM_BOOL T15_;
		T15_ = (NIM_BOOL)0;
		T15_ = !(((*(*(*c).graph).config).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 18)));
		if (!(T15_)) goto LA16_;
		T15_ = ((*c).compilesContextId == ((NI) 0));
		LA16_: ;
		if (!T15_) goto LA17_;
		strTableAdd__tyTgUybFIoow4CX2l5beug((&(*(*c).importTable).symbols), result);
	}
	LA17_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, errorUseQualifier__t5EWYooFsFPeMiRTzdCWFw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NimStringDesc* err;
	NimStringDesc* T1_;
	tyObject_TIdentIter__Oi4goG2ACEsy9cyTe6OCPrA ti;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* candidate;
	NI i;
	T1_ = (NimStringDesc*)0;
	T1_ = rawNewString(((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + 24);
appendString(T1_, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_26));
appendString(T1_, (*(*s).name).s);
appendString(T1_, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_5));
	err = T1_;
	nimZeroMem((void*)(&ti), sizeof(tyObject_TIdentIter__Oi4goG2ACEsy9cyTe6OCPrA));
	candidate = initIdentIter__9bOoZ7latEpanbVkjFO7xFQ((&ti), (*(*c).importTable).symbols, (*s).name);
	i = ((NI) 0);
	{
		while (1) {
			NimStringDesc* T9_;
			NimStringDesc* T10_;
			NimStringDesc* T11_;
			if (!!((candidate == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA3;
			{
				if (!(i == ((NI) 0))) goto LA6_;
				err = resizeString(err, 30);
appendString(err, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_27));
			}
			goto LA4_;
			LA6_: ;
			{
				err = resizeString(err, 1);
appendString(err, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_28));
			}
			LA4_: ;
			T9_ = (NimStringDesc*)0;
			T9_ = rawNewString(((*(*(*candidate).owner).name).s ? (*(*(*candidate).owner).name).s->Sup.len : 0) + ((*(*candidate).name).s ? (*(*candidate).name).s->Sup.len : 0) + 3);
appendString(T9_, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_29));
appendString(T9_, (*(*(*candidate).owner).name).s);
appendString(T9_, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_30));
appendString(T9_, (*(*candidate).name).s);
			err = resizeString(err, (T9_ ? T9_->Sup.len : 0) + 0);
appendString(err, T9_);
			T10_ = (NimStringDesc*)0;
			T11_ = (NimStringDesc*)0;
			T11_ = typeToString__QlvraUan7WbHowhAbvDvdA((*candidate).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T10_ = rawNewString((T11_ ? T11_->Sup.len : 0) + 2);
appendString(T10_, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_31));
appendString(T10_, T11_);
			err = resizeString(err, (T10_ ? T10_->Sup.len : 0) + 0);
appendString(err, T10_);
			candidate = nextIdentIter__9bSCoSykDuXHhkzoBXiof6Q((&ti), (*(*c).importTable).symbols);
			i += ((NI) 1);
		} LA3: ;
	}
	liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), err, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__3uzV357076dKeFHtnMZm2A_32, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TLookupFlag__ObWMY5GMSl1GiMcrKaAhKQ flags) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53):
	{
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
		ident = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, n, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T6_;
			if (!((flags &((NU8)1<<((NU)(((tyEnum_TLookupFlag__ObWMY5GMSl1GiMcrKaAhKQ) 2))&7U)))!=0)) goto LA4_;
			T6_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
			T6_ = searchInScopes__Drn1sJCJSwUUo03qKJigUw(c, ident);
			result = skipAlias__5qYRPQsu9attXO2xg5lnFVQ(T6_, n, (*(*c).graph).config);
		}
		goto LA2_;
		LA4_: ;
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T8_;
			T8_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
			T8_ = searchInScopes__Jp5sb3DT9aETEb2x58UOk6g(c, ident, 50331583);
			result = skipAlias__5qYRPQsu9attXO2xg5lnFVQ(T8_, n, (*(*c).graph).config);
		}
		LA2_: ;
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = (result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
			if (!(T11_)) goto LA12_;
			T11_ = ((flags &((NU8)1<<((NU)(((tyEnum_TLookupFlag__ObWMY5GMSl1GiMcrKaAhKQ) 3))&7U)))!=0);
			LA12_: ;
			if (!T11_) goto LA13_;
			result = strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ((*c).pureEnumFields, ident);
		}
		LA13_: ;
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = (result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
			if (!(T17_)) goto LA18_;
			T17_ = ((flags &((NU8)1<<((NU)(((tyEnum_TLookupFlag__ObWMY5GMSl1GiMcrKaAhKQ) 1))&7U)))!=0);
			LA18_: ;
			if (!T17_) goto LA19_;
			errorUndeclaredIdentifier__2jJM9bqw5w9caMyqez0JSuZw(c, (*n).info, (*ident).s);
			result = errorSym__CLMmoDuBHkJLvNsKvljGNw(c, n);
		}
		goto LA15_;
		LA19_: ;
		{
			NIM_BOOL T22_;
			NIM_BOOL T23_;
			T22_ = (NIM_BOOL)0;
			T23_ = (NIM_BOOL)0;
			T23_ = ((flags &((NU8)1<<((NU)(((tyEnum_TLookupFlag__ObWMY5GMSl1GiMcrKaAhKQ) 0))&7U)))!=0);
			if (!(T23_)) goto LA24_;
			T23_ = !((result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
			LA24_: ;
			T22_ = T23_;
			if (!(T22_)) goto LA25_;
			T22_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*c).ambiguousSymbols), (*result).Sup.id);
			LA25_: ;
			if (!T22_) goto LA26_;
			errorUseQualifier__t5EWYooFsFPeMiRTzdCWFw(c, (*n).info, result);
		}
		goto LA15_;
		LA26_: ;
		LA15_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		result = (*n)._kind_4.sym;
		{
			NIM_BOOL T31_;
			T31_ = (NIM_BOOL)0;
			T31_ = ((flags &((NU8)1<<((NU)(((tyEnum_TLookupFlag__ObWMY5GMSl1GiMcrKaAhKQ) 0))&7U)))!=0);
			if (!(T31_)) goto LA32_;
			T31_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*c).ambiguousSymbols), (*result).Sup.id);
			LA32_: ;
			if (!T31_) goto LA33_;
			errorUseQualifier__t5EWYooFsFPeMiRTzdCWFw(c, (*n).info, (*n)._kind_4.sym);
		}
		LA33_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m;
		result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
		m = qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag(c, (*n)._kind_6.sons->data[((NI) 0)], ((flags & 2) | 4));
		{
			NIM_BOOL T38_;
			tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident_2;
			T38_ = (NIM_BOOL)0;
			T38_ = !((m == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
			if (!(T38_)) goto LA39_;
			T38_ = ((*m).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6));
			LA39_: ;
			if (!T38_) goto LA40_;
			ident_2 = ((tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*) NIM_NIL);
			{
				if (!((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2))) goto LA44_;
				ident_2 = (*(*n)._kind_6.sons->data[((NI) 1)])._kind_5.ident;
			}
			goto LA42_;
			LA44_: ;
			{
				if (!((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53))) goto LA47_;
				ident_2 = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*n)._kind_6.sons->data[((NI) 1)], ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
			}
			goto LA42_;
			LA47_: ;
			LA42_: ;
			{
				if (!!((ident_2 == ((tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*) NIM_NIL)))) goto LA51_;
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T57_;
					if (!(m == (*c).module)) goto LA55_;
					T57_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
					T57_ = strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ((*(*c).topLevelScope).symbols, ident_2);
					result = skipAlias__5qYRPQsu9attXO2xg5lnFVQ(T57_, n, (*(*c).graph).config);
				}
				goto LA53_;
				LA55_: ;
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T59_;
					T59_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
					T59_ = strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ((*m)._kind_3.tab, ident_2);
					result = skipAlias__5qYRPQsu9attXO2xg5lnFVQ(T59_, n, (*(*c).graph).config);
				}
				LA53_: ;
				{
					NIM_BOOL T62_;
					T62_ = (NIM_BOOL)0;
					T62_ = (result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
					if (!(T62_)) goto LA63_;
					T62_ = ((flags &((NU8)1<<((NU)(((tyEnum_TLookupFlag__ObWMY5GMSl1GiMcrKaAhKQ) 1))&7U)))!=0);
					LA63_: ;
					if (!T62_) goto LA64_;
					errorUndeclaredIdentifier__2jJM9bqw5w9caMyqez0JSuZw(c, (*(*n)._kind_6.sons->data[((NI) 1)]).info, (*ident_2).s);
					result = errorSym__CLMmoDuBHkJLvNsKvljGNw(c, (*n)._kind_6.sons->data[((NI) 1)]);
				}
				LA64_: ;
			}
			goto LA49_;
			LA51_: ;
			{
				if (!((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA67_;
				result = (*(*n)._kind_6.sons->data[((NI) 1)])._kind_4.sym;
			}
			goto LA49_;
			LA67_: ;
			{
				NIM_BOOL T70_;
				NimStringDesc* T74_;
				NimStringDesc* T75_;
				T70_ = (NIM_BOOL)0;
				T70_ = ((flags &((NU8)1<<((NU)(((tyEnum_TLookupFlag__ObWMY5GMSl1GiMcrKaAhKQ) 1))&7U)))!=0);
				if (!(T70_)) goto LA71_;
				T70_ = !(((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 57) || (*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 56)));
				LA71_: ;
				if (!T70_) goto LA72_;
				T74_ = (NimStringDesc*)0;
				T75_ = (NimStringDesc*)0;
				T75_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA((*n)._kind_6.sons->data[((NI) 1)], 0);
				T74_ = rawNewString((T75_ ? T75_->Sup.len : 0) + 30);
appendString(T74_, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_33));
appendString(T74_, T75_);
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 1)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T74_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__3uzV357076dKeFHtnMZm2A_34, NIM_FALSE);
				result = errorSym__CLMmoDuBHkJLvNsKvljGNw(c, (*n)._kind_6.sons->data[((NI) 1)]);
			}
			goto LA49_;
			LA72_: ;
			LA49_: ;
		}
		LA40_: ;
	}
	break;
	default:
	{
		result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, initOverloadIter__yTTeeqtnENsm0xyCro9a61w)(tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ* o, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
{	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53):
	{
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
		ident = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, n, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		unsureAsgnRef((void**) (&(*o).scope), (*c).currentScope);
		(*o).mode = ((tyEnum_TOverloadIterMode__xCku9a0wtzKQQBbzX1t6btg) 1);
		{
			while (1) {
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T4_;
				T4_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
				T4_ = initIdentIter__9bOoZ7latEpanbVkjFO7xFQ((&(*o).it), (*(*o).scope).symbols, ident);
				result = skipAlias__5qYRPQsu9attXO2xg5lnFVQ(T4_, n, (*(*c).graph).config);
				{
					if (!!((result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA7_;
					goto LA2;
				}
				goto LA5_;
				LA7_: ;
				{
					unsureAsgnRef((void**) (&(*o).scope), (*(*o).scope).parent);
					{
						if (!((*o).scope == ((tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*) NIM_NIL))) goto LA12_;
						goto LA2;
					}
					LA12_: ;
				}
				LA5_: ;
			}
		} LA2: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		result = (*n)._kind_4.sym;
		(*o).mode = ((tyEnum_TOverloadIterMode__xCku9a0wtzKQQBbzX1t6btg) 0);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45):
	{
		(*o).mode = ((tyEnum_TOverloadIterMode__xCku9a0wtzKQQBbzX1t6btg) 3);
		unsureAsgnRef((void**) (&(*o).m), qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag(c, (*n)._kind_6.sons->data[((NI) 0)], 6));
		{
			NIM_BOOL T18_;
			tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident_2;
			T18_ = (NIM_BOOL)0;
			T18_ = !(((*o).m == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
			if (!(T18_)) goto LA19_;
			T18_ = ((*(*o).m).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6));
			LA19_: ;
			if (!T18_) goto LA20_;
			ident_2 = ((tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*) NIM_NIL);
			{
				if (!((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2))) goto LA24_;
				ident_2 = (*(*n)._kind_6.sons->data[((NI) 1)])._kind_5.ident;
			}
			goto LA22_;
			LA24_: ;
			{
				if (!((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53))) goto LA27_;
				ident_2 = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*n)._kind_6.sons->data[((NI) 1)], n);
			}
			goto LA22_;
			LA27_: ;
			LA22_: ;
			{
				if (!!((ident_2 == ((tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*) NIM_NIL)))) goto LA31_;
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T37_;
					if (!((*o).m == (*c).module)) goto LA35_;
					T37_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
					T37_ = initIdentIter__9bOoZ7latEpanbVkjFO7xFQ((&(*o).it), (*(*c).topLevelScope).symbols, ident_2);
					result = skipAlias__5qYRPQsu9attXO2xg5lnFVQ(T37_, n, (*(*c).graph).config);
					(*o).mode = ((tyEnum_TOverloadIterMode__xCku9a0wtzKQQBbzX1t6btg) 2);
				}
				goto LA33_;
				LA35_: ;
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T39_;
					T39_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
					T39_ = initIdentIter__9bOoZ7latEpanbVkjFO7xFQ((&(*o).it), (*(*o).m)._kind_3.tab, ident_2);
					result = skipAlias__5qYRPQsu9attXO2xg5lnFVQ(T39_, n, (*(*c).graph).config);
				}
				LA33_: ;
			}
			goto LA29_;
			LA31_: ;
			{
				noidentError__HVvM5T79c59bpcZcfRadKowg((*(*c).graph).config, (*n)._kind_6.sons->data[((NI) 1)], n);
				result = errorSym__CLMmoDuBHkJLvNsKvljGNw(c, (*n)._kind_6.sons->data[((NI) 1)]);
			}
			LA29_: ;
		}
		LA20_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 56):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 57):
	{
		(*o).mode = ((tyEnum_TOverloadIterMode__xCku9a0wtzKQQBbzX1t6btg) 4);
		{
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA44_;
			result = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		}
		goto LA42_;
		LA44_: ;
		{
			(*o).mode = ((tyEnum_TOverloadIterMode__xCku9a0wtzKQQBbzX1t6btg) 0);
			result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
			goto BeforeRet_;
		}
		LA42_: ;
		(*o).symChoiceIndex = ((NI) 1);
		initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&(*o).inSymChoice));
		incl__jENnK9c9bPE73pKmo2vYjpqg((&(*o).inSymChoice), (*result).Sup.id);
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, nextOverloadIter__yTTeeqtnENsm0xyCro9a61w_2)(tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ* o, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	switch ((*o).mode) {
	case ((tyEnum_TOverloadIterMode__xCku9a0wtzKQQBbzX1t6btg) 0):
	{
		result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
	}
	break;
	case ((tyEnum_TOverloadIterMode__xCku9a0wtzKQQBbzX1t6btg) 1):
	{
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T7_;
			if (!!(((*o).scope == ((tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*) NIM_NIL)))) goto LA5_;
			T7_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
			T7_ = nextIdentIter__9bSCoSykDuXHhkzoBXiof6Q((&(*o).it), (*(*o).scope).symbols);
			result = skipAlias__5qYRPQsu9attXO2xg5lnFVQ(T7_, n, (*(*c).graph).config);
			{
				while (1) {
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T14_;
					if (!(result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA9;
					unsureAsgnRef((void**) (&(*o).scope), (*(*o).scope).parent);
					{
						if (!((*o).scope == ((tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*) NIM_NIL))) goto LA12_;
						goto LA8;
					}
					LA12_: ;
					T14_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
					T14_ = initIdentIter__9bOoZ7latEpanbVkjFO7xFQ((&(*o).it), (*(*o).scope).symbols, (*o).it.name);
					result = skipAlias__5qYRPQsu9attXO2xg5lnFVQ(T14_, n, (*(*c).graph).config);
				} LA9: ;
			} LA8: ;
		}
		goto LA3_;
		LA5_: ;
		{
			result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
		}
		LA3_: ;
	}
	break;
	case ((tyEnum_TOverloadIterMode__xCku9a0wtzKQQBbzX1t6btg) 2):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T17_;
		T17_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T17_ = nextIdentIter__9bSCoSykDuXHhkzoBXiof6Q((&(*o).it), (*(*c).topLevelScope).symbols);
		result = skipAlias__5qYRPQsu9attXO2xg5lnFVQ(T17_, n, (*(*c).graph).config);
	}
	break;
	case ((tyEnum_TOverloadIterMode__xCku9a0wtzKQQBbzX1t6btg) 3):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T19_;
		T19_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T19_ = nextIdentIter__9bSCoSykDuXHhkzoBXiof6Q((&(*o).it), (*(*o).m)._kind_3.tab);
		result = skipAlias__5qYRPQsu9attXO2xg5lnFVQ(T19_, n, (*(*c).graph).config);
	}
	break;
	case ((tyEnum_TOverloadIterMode__xCku9a0wtzKQQBbzX1t6btg) 4):
	{
		{
			NI T23_;
			T23_ = (NI)0;
			T23_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!((*o).symChoiceIndex < T23_)) goto LA24_;
			result = (*(*n)._kind_6.sons->data[(*o).symChoiceIndex])._kind_4.sym;
			incl__jENnK9c9bPE73pKmo2vYjpqg((&(*o).inSymChoice), (*result).Sup.id);
			(*o).symChoiceIndex += ((NI) 1);
		}
		goto LA21_;
		LA24_: ;
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T29_;
			if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 57))) goto LA27_;
			(*o).mode = ((tyEnum_TOverloadIterMode__xCku9a0wtzKQQBbzX1t6btg) 5);
			unsureAsgnRef((void**) (&(*o).scope), (*c).currentScope);
			T29_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
			T29_ = firstIdentExcluding__ZgFGN4FdEZomWhiPqs5O3Q((&(*o).it), (*(*o).scope).symbols, (*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name, (&(*o).inSymChoice));
			result = skipAlias__5qYRPQsu9attXO2xg5lnFVQ(T29_, n, (*(*c).graph).config);
			{
				while (1) {
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T36_;
					if (!(result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA31;
					unsureAsgnRef((void**) (&(*o).scope), (*(*o).scope).parent);
					{
						if (!((*o).scope == ((tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*) NIM_NIL))) goto LA34_;
						goto LA30;
					}
					LA34_: ;
					T36_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
					T36_ = firstIdentExcluding__ZgFGN4FdEZomWhiPqs5O3Q((&(*o).it), (*(*o).scope).symbols, (*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name, (&(*o).inSymChoice));
					result = skipAlias__5qYRPQsu9attXO2xg5lnFVQ(T36_, n, (*(*c).graph).config);
				} LA31: ;
			} LA30: ;
		}
		goto LA21_;
		LA27_: ;
		LA21_: ;
	}
	break;
	case ((tyEnum_TOverloadIterMode__xCku9a0wtzKQQBbzX1t6btg) 5):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T38_;
		T38_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T38_ = nextIdentExcluding__nWv58txbq3B5NUvjC6qnSA((&(*o).it), (*(*o).scope).symbols, (&(*o).inSymChoice));
		result = skipAlias__5qYRPQsu9attXO2xg5lnFVQ(T38_, n, (*(*c).graph).config);
		{
			while (1) {
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T45_;
				if (!(result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA40;
				unsureAsgnRef((void**) (&(*o).scope), (*(*o).scope).parent);
				{
					if (!((*o).scope == ((tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*) NIM_NIL))) goto LA43_;
					goto LA39;
				}
				LA43_: ;
				T45_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
				T45_ = firstIdentExcluding__ZgFGN4FdEZomWhiPqs5O3Q((&(*o).it), (*(*o).scope).symbols, (*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name, (&(*o).inSymChoice));
				result = skipAlias__5qYRPQsu9attXO2xg5lnFVQ(T45_, n, (*(*c).graph).config);
			} LA40: ;
		} LA39: ;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, lastOverloadScope__8ksyNJM57vm1Sx3GOp09acw)(tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ* o) {
	NI result;
	result = (NI)0;
	switch ((*o).mode) {
	case ((tyEnum_TOverloadIterMode__xCku9a0wtzKQQBbzX1t6btg) 1):
	{
		{
			if (!((*o).scope == 0)) goto LA4_;
			result = ((NI) -1);
		}
		goto LA2_;
		LA4_: ;
		{
			result = (*(*o).scope).depthLevel;
		}
		LA2_: ;
	}
	break;
	case ((tyEnum_TOverloadIterMode__xCku9a0wtzKQQBbzX1t6btg) 2):
	{
		result = ((NI) 1);
	}
	break;
	case ((tyEnum_TOverloadIterMode__xCku9a0wtzKQQBbzX1t6btg) 3):
	{
		result = ((NI) 0);
	}
	break;
	default:
	{
		result = ((NI) -1);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, addUniqueSym__77zA8kzVYm6Us7mD6cMg6A)(tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	result = strTableInclReportConflict__tsV7rrfL6ZnfCXBjJk0jUA((&(*scope).symbols), s, NIM_FALSE);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addPrelimDecl__aPXKqZJT9c7r7gT8X3uZAHw_4)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T1_;
	T1_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = addUniqueSym__77zA8kzVYm6Us7mD6cMg6A((*c).currentScope, sym);
	(void)(T1_);
}
N_LIB_PRIVATE N_NIMCALL(void, addDeclAt__HcojHyPBYsbchSQtmBqThg_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* conflict;
	conflict = addUniqueSym__77zA8kzVYm6Us7mD6cMg6A(scope, sym);
	{
		if (!!((conflict == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA3_;
		wrongRedefinition__m38oZS3DB39a2RtTLWidA5w(c, (*sym).info, (*(*sym).name).s, (*conflict).info);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addInterfaceDeclAt__HcojHyPBYsbchSQtmBqThg_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym) {
	addDeclAt__HcojHyPBYsbchSQtmBqThg_3(c, scope, sym);
	addInterfaceDeclAux__aPXKqZJT9c7r7gT8X3uZAHw_2(c, sym);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, lookUp__CLMmoDuBHkJLvNsKvljGNw_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
{	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T2_;
		T2_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T2_ = searchInScopes__Drn1sJCJSwUUo03qKJigUw(c, (*n)._kind_5.ident);
		result = skipAlias__5qYRPQsu9attXO2xg5lnFVQ(T2_, n, (*(*c).graph).config);
		{
			if (!(result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA5_;
			errorUndeclaredIdentifier__2jJM9bqw5w9caMyqez0JSuZw(c, (*n).info, (*(*n)._kind_5.ident).s);
			result = errorSym__CLMmoDuBHkJLvNsKvljGNw(c, n);
		}
		LA5_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		result = (*n)._kind_4.sym;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53):
	{
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T9_;
		ident = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, n, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		T9_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T9_ = searchInScopes__Drn1sJCJSwUUo03qKJigUw(c, ident);
		result = skipAlias__5qYRPQsu9attXO2xg5lnFVQ(T9_, n, (*(*c).graph).config);
		{
			if (!(result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA12_;
			errorUndeclaredIdentifier__2jJM9bqw5w9caMyqez0JSuZw(c, (*n).info, (*ident).s);
			result = errorSym__CLMmoDuBHkJLvNsKvljGNw(c, n);
		}
		LA12_: ;
	}
	break;
	default:
	{
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, (*n).info, ((NimStringDesc*) &TM__3uzV357076dKeFHtnMZm2A_35), TM__3uzV357076dKeFHtnMZm2A_36);
		goto BeforeRet_;
	}
	break;
	}
	{
		NIM_BOOL T17_;
		T17_ = (NIM_BOOL)0;
		T17_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*c).ambiguousSymbols), (*result).Sup.id);
		if (!T17_) goto LA18_;
		errorUseQualifier__t5EWYooFsFPeMiRTzdCWFw(c, (*n).info, result);
	}
	LA18_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, pickSym__SVsbCvrhrWQIRF0pM3cw5Q)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kinds, tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ o;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* a;
{	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	nimZeroMem((void*)(&o), sizeof(tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ));
	a = initOverloadIter__yTTeeqtnENsm0xyCro9a61w((&o), c, n);
	{
		while (1) {
			if (!!((a == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA2;
			{
				NIM_BOOL T5_;
				T5_ = (NIM_BOOL)0;
				T5_ = ((kinds &((NU32)1<<((NU)((*a).kind)&31U)))!=0);
				if (!(T5_)) goto LA6_;
				T5_ = ((flags & ~ (*a).flags)==0);
				LA6_: ;
				if (!T5_) goto LA7_;
				{
					if (!(result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA11_;
					result = a;
				}
				goto LA9_;
				LA11_: ;
				{
					result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
					goto BeforeRet_;
				}
				LA9_: ;
			}
			LA7_: ;
			a = nextOverloadIter__yTTeeqtnENsm0xyCro9a61w_2((&o), c, n);
		} LA2: ;
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isShadowScope__S1jnHolp9bBTKeEAk0tUmLwlookups)(tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* s) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = !(((*s).parent == ((tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*) NIM_NIL)));
	if (!(T1_)) goto LA2_;
	T1_ = ((*(*s).parent).depthLevel == (*s).depthLevel);
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, localSearchInScope__Drn1sJCJSwUUo03qKJigUw_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* s) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	scope = (*c).currentScope;
	result = strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ((*scope).symbols, s);
	{
		while (1) {
			NIM_BOOL T3_;
			T3_ = (NIM_BOOL)0;
			T3_ = (result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
			if (!(T3_)) goto LA4_;
			T3_ = isShadowScope__S1jnHolp9bBTKeEAk0tUmLwlookups(scope);
			LA4_: ;
			if (!T3_) goto LA2;
			scope = (*scope).parent;
			result = strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ((*scope).symbols, s);
		} LA2: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addDecl__1NtyWdKavnU9cML29b40tLYQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* conflict;
	conflict = addUniqueSym__77zA8kzVYm6Us7mD6cMg6A((*c).currentScope, sym);
	{
		if (!!((conflict == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA3_;
		wrongRedefinition__m38oZS3DB39a2RtTLWidA5w(c, info, (*(*sym).name).s, (*conflict).info);
	}
	LA3_: ;
}
